@@ -1,5 +1,6 @@
 
-#pragma once
+#ifndef INDICATORS_CURSOR_CONTROL
+#define INDICATORS_CURSOR_CONTROL
 
 #if defined(_MSC_VER)
 #if !defined(NOMINMAX)
@@ -33,4 +34,6 @@ static inline void show_console_cursor(bool const show) {
 
 #endif
 
-} // namespace indicators
\ No newline at end of file
+} // namespace indicators
+
+#endif
\ No newline at end of file
