@@ -1,5 +1,6 @@
 
-#pragma once
+#ifndef INDICATORS_INDETERMINATE_PROGRESS_BAR
+#define INDICATORS_INDETERMINATE_PROGRESS_BAR
 
 #include <indicators/details/stream_helper.hpp>
 
@@ -232,3 +233,5 @@ public:
 };
 
 } // namespace indicators
+
+#endif
\ No newline at end of file
