@@ -1,6 +1,9 @@
 
-#pragma once
+#ifndef INDICATORS_PROGRESS_TYPE
+#define INDICATORS_PROGRESS_TYPE
 
 namespace indicators {
 enum class ProgressType { incremental, decremental };
 }
+
+#endif
\ No newline at end of file
